@@ -218,7 +218,7 @@ namespace KBibTeX
         TQBuffer buffer;
         buffer.open( IO_WriteOnly );
         BibTeX::FileExporterBibTeX * exporter = new BibTeX::FileExporterBibTeX();
-        connect( exporter, SIGNAL( progress( int, int ) ), this, SLOT( updateProgress( int, int ) ) );
+        connect( exporter, TQ_SIGNAL( progress( int, int ) ), this, TQ_SLOT( updateProgress( int, int ) ) );
         exporter->setStringDelimiter( settings->fileIO_BibtexStringOpenDelimiter, settings->fileIO_BibtexStringCloseDelimiter );
         exporter->setKeywordCasing( settings->fileIO_KeywordCasing );
         exporter->setEncoding( "latex" );
@@ -296,7 +296,7 @@ namespace KBibTeX
         m_editInterface = editInterface( m_document );
         m_document->setReadWrite( !m_isReadOnly );
         if ( !m_isReadOnly )
-            connect( m_document, SIGNAL( textChanged() ), this, SIGNAL( modified() ) );
+            connect( m_document, TQ_SIGNAL( textChanged() ), this, TQ_SIGNAL( modified() ) );
         TQBoxLayout * layout = new TQVBoxLayout( this );
         layout->addWidget( static_cast<TQWidget*>( m_view ) );
 
