@@ -51,7 +51,7 @@ namespace KBibTeX
 
     class DocumentWidget : public TQTabWidget
     {
-        Q_OBJECT
+        TQ_OBJECT
     public:
         DocumentWidget( bool isReadOnly, TQWidget *parent = 0, const char *name = 0 );
         ~DocumentWidget();
