@@ -48,7 +48,7 @@ namespace KBibTeX
 
     class EntryWidget : public TQWidget
     {
-        Q_OBJECT
+        TQ_OBJECT
 
         friend class EntryWidgetDialog;
 
@@ -121,7 +121,7 @@ namespace KBibTeX
 
     class EntryWidgetDialog: public KDialogBase
     {
-        Q_OBJECT
+        TQ_OBJECT
     public:
         EntryWidgetDialog( TQWidget *parent = 0, const char *name = 0, bool modal = true, const TQString &caption = TQString::null, int buttonMask = Ok | Apply | Cancel ) : KDialogBase( parent, name, modal, caption, buttonMask ) {/* nothing */};
         ~EntryWidgetDialog() {/* nothing */};
