@@ -192,7 +192,7 @@ namespace KBibTeX
     {
         KeywordListViewItem * item = new KeywordListViewItem( m_listviewKeywords, TQString( i18n( "May only contain ASCII characters, in case of doubt keep English form", "NewKeyword%1" ) ).arg( ++m_numKeywords ), FALSE );
         m_listviewKeywords->setSelected( item, TRUE );
-        TQTimer::singleShot( 100, this, SLOT( slotEditKeyword() ) );
+        TQTimer::singleShot( 100, this, TQ_SLOT( slotEditKeyword() ) );
     }
 
     void EntryWidgetKeyword::slotEditKeyword()
@@ -231,30 +231,30 @@ namespace KBibTeX
         m_listviewKeywords->addColumn( i18n( "Origin" ) );
         gridLayout->addMultiCellWidget( m_listviewKeywords, 0, 4, 0, 0 );
         m_listviewKeywords->setAllColumnsShowFocus( TRUE );
-        connect( m_listviewKeywords, SIGNAL( currentChanged( TQListViewItem* ) ), this, SLOT( slotSelectionChanged() ) );
-        connect( m_listviewKeywords, SIGNAL( clicked( TQListViewItem * ) ), this, SLOT( slotSelectionChanged() ) );
-        connect( m_listviewKeywords, SIGNAL( itemRenamed( TQListViewItem*, const TQString&, int ) ), this, SLOT( slotKeywordRenamed( TQListViewItem*, const TQString&, int ) ) );
+        connect( m_listviewKeywords, TQ_SIGNAL( currentChanged( TQListViewItem* ) ), this, TQ_SLOT( slotSelectionChanged() ) );
+        connect( m_listviewKeywords, TQ_SIGNAL( clicked( TQListViewItem * ) ), this, TQ_SLOT( slotSelectionChanged() ) );
+        connect( m_listviewKeywords, TQ_SIGNAL( itemRenamed( TQListViewItem*, const TQString&, int ) ), this, TQ_SLOT( slotKeywordRenamed( TQListViewItem*, const TQString&, int ) ) );
 
         m_buttonNew = new TQPushButton( i18n( "keyword", "New" ), this );
         m_buttonNew->setEnabled( !m_isReadOnly );
         m_buttonNew->setIconSet( TQIconSet( SmallIcon( "add" ) ) );
         TQToolTip::add( m_buttonNew, i18n( "Add a new keyword to the list" ) );
         gridLayout->addWidget( m_buttonNew, 0, 1 );
-        connect( m_buttonNew, SIGNAL( clicked() ), this, SLOT( slotNewKeyword() ) );
+        connect( m_buttonNew, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotNewKeyword() ) );
 
         m_buttonEdit = new TQPushButton( i18n( "keyword", "Edit" ), this );
         m_buttonEdit->setIconSet( TQIconSet( SmallIcon( "edit" ) ) );
         TQToolTip::add( m_buttonEdit, i18n( "Edit the selected keyword" ) );
         gridLayout->addWidget( m_buttonEdit, 1, 1 );
         m_buttonEdit->setEnabled( FALSE );
-        connect( m_buttonEdit, SIGNAL( clicked() ), this, SLOT( slotEditKeyword() ) );
+        connect( m_buttonEdit, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotEditKeyword() ) );
 
         m_buttonToggleGlobal = new TQPushButton( i18n( "keyword", "Toggle &global" ), this );
         m_buttonToggleGlobal->setIconSet( TQIconSet( SmallIcon( "package" ) ) );
         TQToolTip::add( m_buttonToggleGlobal, i18n( "Add or remove the selected keyword to or from the global list" ) );
         gridLayout->addWidget( m_buttonToggleGlobal, 2, 1 );
         m_buttonToggleGlobal->setEnabled( FALSE );
-        connect( m_buttonToggleGlobal, SIGNAL( clicked() ), this, SLOT( slotToggleGlobal() ) );
+        connect( m_buttonToggleGlobal, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotToggleGlobal() ) );
 
         TQLabel *label = new TQLabel( i18n( "There is no need to delete keywords. Simply uncheck unwanted keywords and make them non-global.\nGlobal keywords can also be edited in the settings dialog." ), this );
         label->setAlignment( TQLabel::WordBreak | TQLabel::AlignTop );
