@@ -176,12 +176,12 @@ namespace KBibTeX
         m_pushButtonAdd->setEnabled( FALSE );
         m_pushButtonDelete->setEnabled( FALSE );
 
-        connect( m_listViewFields, SIGNAL( clicked( TQListViewItem*, const TQPoint&, int ) ), this, SLOT( fieldExecute( TQListViewItem* ) ) );
-        connect( m_lineEditKey, SIGNAL( textChanged( const TQString& ) ), this, SLOT( updateGUI() ) );
-        connect( m_fieldLineEditValue, SIGNAL( textChanged( ) ), this, SLOT( updateGUI() ) );
-        connect( m_pushButtonAdd, SIGNAL( clicked( ) ), this, SLOT( addClicked( ) ) );
-        connect( m_pushButtonDelete, SIGNAL( clicked( ) ), this, SLOT( deleteClicked( ) ) );
-        connect( m_pushButtonOpen, SIGNAL( clicked() ), this, SLOT( openClicked() ) );
+        connect( m_listViewFields, TQ_SIGNAL( clicked( TQListViewItem*, const TQPoint&, int ) ), this, TQ_SLOT( fieldExecute( TQListViewItem* ) ) );
+        connect( m_lineEditKey, TQ_SIGNAL( textChanged( const TQString& ) ), this, TQ_SLOT( updateGUI() ) );
+        connect( m_fieldLineEditValue, TQ_SIGNAL( textChanged( ) ), this, TQ_SLOT( updateGUI() ) );
+        connect( m_pushButtonAdd, TQ_SIGNAL( clicked( ) ), this, TQ_SLOT( addClicked( ) ) );
+        connect( m_pushButtonDelete, TQ_SIGNAL( clicked( ) ), this, TQ_SLOT( deleteClicked( ) ) );
+        connect( m_pushButtonOpen, TQ_SIGNAL( clicked() ), this, TQ_SLOT( openClicked() ) );
     }
 
     void EntryWidgetOther::updateGUI()
