@@ -172,7 +172,7 @@ namespace KBibTeX
 
     void FieldListView::updateGUI()
     {
-        disconnect( m_checkBoxEtAl, SIGNAL( toggled( bool ) ), this, SLOT( apply() ) );
+        disconnect( m_checkBoxEtAl, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( apply() ) );
         if ( m_value != NULL && !m_isComplex )
         {
             bool isElementSelected = m_listViewElements->selectedItem() != NULL;
@@ -194,7 +194,7 @@ namespace KBibTeX
             m_listViewElements->setEnabled( FALSE );
             m_checkBoxEtAl->setEnabled( FALSE );
         }
-        connect( m_checkBoxEtAl, SIGNAL( toggled( bool ) ), this, SLOT( apply() ) );
+        connect( m_checkBoxEtAl, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( apply() ) );
     }
 
     void FieldListView::slotAdd()
@@ -204,7 +204,7 @@ namespace KBibTeX
             TDEListViewItem * item = new TDEListViewItem( m_listViewElements, m_listViewElements->lastItem(), TQString( "%1%2" ).arg( m_prefixNew ).arg( ++m_newValueCounter ) );
             m_listViewElements->setSelected( item, TRUE );
             updateGUI();
-            TQTimer::singleShot( 100, this, SLOT( slotEdit() ) );
+            TQTimer::singleShot( 100, this, TQ_SLOT( slotEdit() ) );
         }
     }
 
@@ -308,51 +308,51 @@ namespace KBibTeX
 
         m_listViewElements->header() ->setClickEnabled( FALSE );
         m_listViewElements->header() ->setStretchEnabled( TRUE, 0 );
-        connect( m_listViewElements, SIGNAL( selectionChanged() ), this, SLOT( updateGUI() ) );
-        connect( m_listViewElements, SIGNAL( clicked( TQListViewItem * ) ), this, SLOT( updateGUI() ) );
-        connect( m_listViewElements, SIGNAL( doubleClicked( TQListViewItem * ) ), this, SLOT( slotListViewDoubleClicked( TQListViewItem * ) ) );
-        connect( m_listViewElements, SIGNAL( currentChanged( TQListViewItem * ) ), this, SLOT( updateGUI() ) );
-        connect( m_listViewElements, SIGNAL( itemRenamed( TQListViewItem*, int, const TQString& ) ), this, SLOT( slotItemRenamed( TQListViewItem*, int, const TQString& ) ) );
+        connect( m_listViewElements, TQ_SIGNAL( selectionChanged() ), this, TQ_SLOT( updateGUI() ) );
+        connect( m_listViewElements, TQ_SIGNAL( clicked( TQListViewItem * ) ), this, TQ_SLOT( updateGUI() ) );
+        connect( m_listViewElements, TQ_SIGNAL( doubleClicked( TQListViewItem * ) ), this, TQ_SLOT( slotListViewDoubleClicked( TQListViewItem * ) ) );
+        connect( m_listViewElements, TQ_SIGNAL( currentChanged( TQListViewItem * ) ), this, TQ_SLOT( updateGUI() ) );
+        connect( m_listViewElements, TQ_SIGNAL( itemRenamed( TQListViewItem*, int, const TQString& ) ), this, TQ_SLOT( slotItemRenamed( TQListViewItem*, int, const TQString& ) ) );
 
         m_pushButtonAdd = new TQPushButton( i18n( "Add" ), this );
         layout->addWidget( m_pushButtonAdd, 0, 1 );
         m_pushButtonAdd->setIconSet( TQIconSet( SmallIcon( "add" ) ) );
-        connect( m_pushButtonAdd, SIGNAL( clicked() ), this, SLOT( slotAdd() ) );
+        connect( m_pushButtonAdd, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotAdd() ) );
         TQToolTip::add( m_pushButtonAdd, TQString( i18n( "Add new '%1' item (Ctrl+A)" ) ).arg( m_caption ) );
 
         m_pushButtonEdit = new TQPushButton( i18n( "Edit" ), this );
         layout->addWidget( m_pushButtonEdit, 1, 1 );
         m_pushButtonEdit->setIconSet( TQIconSet( SmallIcon( "edit" ) ) );
-        connect( m_pushButtonEdit, SIGNAL( clicked() ), this, SLOT( slotEdit() ) );
+        connect( m_pushButtonEdit, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotEdit() ) );
         TQToolTip::add( m_pushButtonEdit, TQString( i18n( "Edit current '%1' item (F2)" ) ).arg( m_caption ) );
 
         m_pushButtonDelete = new TQPushButton( i18n( "Delete" ), this );
         layout->addWidget( m_pushButtonDelete, 2, 1 );
         m_pushButtonDelete->setIconSet( TQIconSet( SmallIcon( "edit-delete" ) ) );
-        connect( m_pushButtonDelete, SIGNAL( clicked() ), this, SLOT( slotDelete() ) );
+        connect( m_pushButtonDelete, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotDelete() ) );
         TQToolTip::add( m_pushButtonDelete, TQString( i18n( "Delete current '%1' item (Del)" ) ).arg( m_caption ) );
 
         m_pushButtonUp = new TQPushButton( i18n( "Up" ), this );
         layout->addWidget( m_pushButtonUp, 3, 1 );
         m_pushButtonUp->setIconSet( TQIconSet( SmallIcon( "go-up" ) ) );
-        connect( m_pushButtonUp, SIGNAL( clicked() ), this, SLOT( slotUp() ) );
+        connect( m_pushButtonUp, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotUp() ) );
         TQToolTip::add( m_pushButtonUp, TQString( i18n( "Move current '%1' item up (Ctrl+Up)" ) ).arg( m_caption ) );
 
         m_pushButtonDown = new TQPushButton( i18n( "Down" ), this );
         layout->addWidget( m_pushButtonDown, 4, 1 );
         m_pushButtonDown->setIconSet( TQIconSet( SmallIcon( "go-down" ) ) );
-        connect( m_pushButtonDown, SIGNAL( clicked() ), this, SLOT( slotDown() ) );
+        connect( m_pushButtonDown, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotDown() ) );
         TQToolTip::add( m_pushButtonDown, TQString( i18n( "Move current '%1' item down (Ctrl+Down)" ) ).arg( m_caption ) );
 
         m_pushButtonComplexEdit = new TQPushButton( i18n( "Complex..." ), this );
         layout->addWidget( m_pushButtonComplexEdit, 6, 1 );
         m_pushButtonComplexEdit->setIconSet( TQIconSet( SmallIcon( "format-justify-left" ) ) );
-        connect( m_pushButtonComplexEdit, SIGNAL( clicked() ), this, SLOT( slotComplex() ) );
+        connect( m_pushButtonComplexEdit, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotComplex() ) );
         TQToolTip::add( m_pushButtonComplexEdit, TQString( i18n( "Edit current '%1' item as a concatenated string (Ctrl+Alt+C)" ) ).arg( m_caption ) );
 
         m_checkBoxEtAl = new TQCheckBox( i18n( "... and others (et al.)" ), this );
         layout->addMultiCellWidget( m_checkBoxEtAl, 7, 7, 0, 1 );
-        connect( m_checkBoxEtAl, SIGNAL( toggled( bool ) ), this, SLOT( apply() ) );
+        connect( m_checkBoxEtAl, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( apply() ) );
     }
 
     void FieldListView::apply()
@@ -403,7 +403,7 @@ namespace KBibTeX
 
     void FieldListView::reset()
     {
-        disconnect( m_checkBoxEtAl, SIGNAL( toggled( bool ) ), this, SLOT( apply() ) );
+        disconnect( m_checkBoxEtAl, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( apply() ) );
         m_listViewElements->clear();
         m_checkBoxEtAl->setChecked( FALSE );
 
@@ -439,7 +439,7 @@ namespace KBibTeX
                 kdDebug() << "Don't know how to handle entries of type " << BibTeX::EntryField::fieldTypeToString( m_fieldType ) << endl;
             }
 
-        connect( m_checkBoxEtAl, SIGNAL( toggled( bool ) ), this, SLOT( apply() ) );
+        connect( m_checkBoxEtAl, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( apply() ) );
     }
 
     bool FieldListView::isSimple()
