@@ -108,10 +108,10 @@ namespace BibTeX
         TQApplication::setOverrideCursor( TQt::waitCursor );
 
         process = new TQProcess( args );
-        connect( process, SIGNAL( processExited() ), this, SLOT( slotProcessExited() ) );
-        connect( process, SIGNAL( readyReadStdout() ), this, SLOT( slotReadProcessOutput() ) );
-        connect( process, SIGNAL( readyReadStderr() ), this, SLOT( slotReadProcessOutput() ) );
-        connect( process, SIGNAL( wroteToStdin() ), this, SLOT( slotWroteToStdin() ) );
+        connect( process, TQ_SIGNAL( processExited() ), this, TQ_SLOT( slotProcessExited() ) );
+        connect( process, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( slotReadProcessOutput() ) );
+        connect( process, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( slotReadProcessOutput() ) );
+        connect( process, TQ_SIGNAL( wroteToStdin() ), this, TQ_SLOT( slotWroteToStdin() ) );
 
         if ( process->start() )
         {
@@ -136,10 +136,10 @@ namespace BibTeX
             result = process->normalExit();
         }
 
-        disconnect( process, SIGNAL( wroteToStdin() ), this, SLOT( slotWroteToStdin() ) );
-        disconnect( process, SIGNAL( readyReadStdout() ), this, SLOT( slotReadProcessOutput() ) );
-        disconnect( process, SIGNAL( readyReadStderr() ), this, SLOT( slotReadProcessOutput() ) );
-        disconnect( process, SIGNAL( processExited() ), this, SLOT( slotProcessExited() ) );
+        disconnect( process, TQ_SIGNAL( wroteToStdin() ), this, TQ_SLOT( slotWroteToStdin() ) );
+        disconnect( process, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( slotReadProcessOutput() ) );
+        disconnect( process, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( slotReadProcessOutput() ) );
+        disconnect( process, TQ_SIGNAL( processExited() ), this, TQ_SLOT( slotProcessExited() ) );
         delete( process );
         process = NULL;
         delete writeTo;
