@@ -65,9 +65,9 @@ namespace BibTeX
 
         m_process = new TQProcess( args );
         m_process->setWorkingDirectory( workingDir );
-        connect( m_process, SIGNAL( processExited() ), this, SLOT( slotProcessExited() ) );
-        connect( m_process, SIGNAL( readyReadStdout() ), this, SLOT( slotReadProcessOutput() ) );
-        connect( m_process, SIGNAL( readyReadStderr() ), this, SLOT( slotReadProcessOutput() ) );
+        connect( m_process, TQ_SIGNAL( processExited() ), this, TQ_SLOT( slotProcessExited() ) );
+        connect( m_process, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( slotReadProcessOutput() ) );
+        connect( m_process, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( slotReadProcessOutput() ) );
 
         if ( m_process->start() )
         {
@@ -92,9 +92,9 @@ namespace BibTeX
             errorLog->append( TQString( "Process '%1' was not started." ).arg( args.join( " " ) ) );
 
 
-        disconnect( m_process, SIGNAL( readyReadStdout() ), this, SLOT( slotReadProcessOutput() ) );
-        disconnect( m_process, SIGNAL( readyReadStderr() ), this, SLOT( slotReadProcessOutput() ) );
-        disconnect( m_process, SIGNAL( processExited() ), this, SLOT( slotProcessExited() ) );
+        disconnect( m_process, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( slotReadProcessOutput() ) );
+        disconnect( m_process, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( slotReadProcessOutput() ) );
+        disconnect( m_process, TQ_SIGNAL( processExited() ), this, TQ_SLOT( slotProcessExited() ) );
         delete( m_process );
         m_process = NULL;
 
