@@ -35,7 +35,7 @@ namespace BibTeX
     */
     class FileImporterExternal : public FileImporter
     {
-        Q_OBJECT
+        TQ_OBJECT
     public:
         enum Importer {importerNone = 0, importerBibConv = 4};
 
