@@ -56,7 +56,7 @@ namespace KBibTeX
 
         TQApplication::setOverrideCursor( TQt::waitCursor );
         KProgressDialog *progDlg = new KProgressDialog( parent, NULL, i18n( "Find Duplicates" ), i18n( "Searching for duplicates..." ), true );
-        connect( progDlg, SIGNAL( cancelClicked() ), this, SLOT( slotCancel() ) );
+        connect( progDlg, TQ_SIGNAL( cancelClicked() ), this, TQ_SLOT( slotCancel() ) );
         progDlg->progressBar()->setTotalSteps( len );
 
         determineDistances( file, distVector, mapElementToIndex, progDlg );
