@@ -63,9 +63,9 @@ namespace KBibTeX
         layout->addWidget( m_pushButtonDown );
         layout->addWidget( m_pushButtonDel );
         layout->addStretch( 10 );
-        connect( m_pushButtonUp, SIGNAL( clicked() ), this, SLOT( slotUp() ) );
-        connect( m_pushButtonDown, SIGNAL( clicked() ), this, SLOT( slotDown() ) );
-        connect( m_pushButtonDel, SIGNAL( clicked() ), this, SLOT( slotDelete() ) );
+        connect( m_pushButtonUp, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotUp() ) );
+        connect( m_pushButtonDown, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotDown() ) );
+        connect( m_pushButtonDel, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotDelete() ) );
         return container;
     }
 
@@ -133,7 +133,7 @@ namespace KBibTeX
         case 'z': m_comboBoxWhichAuthors->setCurrentItem( 2 ); break;
         default: m_comboBoxWhichAuthors->setCurrentItem( 0 );
         }
-        connect( m_comboBoxWhichAuthors, SIGNAL( activated( const TQString& ) ), SIGNAL( modified() ) );
+        connect( m_comboBoxWhichAuthors, TQ_SIGNAL( activated( const TQString& ) ), TQ_SIGNAL( modified() ) );
 
         struct IdSuggestionTokenInfo info = IdSuggestions::evalToken( text.mid( 1 ) );
 
@@ -151,7 +151,7 @@ namespace KBibTeX
             m_comboBoxCasing->setCurrentItem( 2 );
         else
             m_comboBoxCasing->setCurrentItem( 0 );
-        connect( m_comboBoxCasing, SIGNAL( activated( const TQString& ) ), SIGNAL( modified() ) );
+        connect( m_comboBoxCasing, TQ_SIGNAL( activated( const TQString& ) ), TQ_SIGNAL( modified() ) );
 
         label = new TQLabel( i18n( "Only first letters:" ), this );
         layout->addWidget( label, 3, 0 );
@@ -163,7 +163,7 @@ namespace KBibTeX
         m_spinBoxLen->setSpecialValueText( i18n( "Complete name" ) );
         m_spinBoxLen->setValue( info.len > 9 ? 0 : info.len );
         m_spinBoxLen->setMinimumWidth( m_spinBoxLen->fontMetrics().width( i18n( "Complete name" ) ) + 32 );
-        connect( m_spinBoxLen, SIGNAL( valueChanged( int ) ), SIGNAL( modified() ) );
+        connect( m_spinBoxLen, TQ_SIGNAL( valueChanged( int ) ), TQ_SIGNAL( modified() ) );
 
         label = new TQLabel( i18n( "Text between authors:" ), this );
         layout->addWidget( label, 4, 0 );
@@ -171,7 +171,7 @@ namespace KBibTeX
         label->setBuddy( m_lineEditInBetween );
         layout->addWidget( m_lineEditInBetween, 4, 1 );
         m_lineEditInBetween->setText( info.inBetween );
-        connect( m_lineEditInBetween, SIGNAL( textChanged( const TQString& ) ), SIGNAL( modified() ) );
+        connect( m_lineEditInBetween, TQ_SIGNAL( textChanged( const TQString& ) ), TQ_SIGNAL( modified() ) );
 
         layout->setRowStretch( 5, 1 );
         layout->setColStretch( 1, 1 );
@@ -214,7 +214,7 @@ namespace KBibTeX
         m_checkBoxRemoveSmallWords = new TQCheckBox( i18n( "Remove small words" ), this );
         layout->addMultiCellWidget( m_checkBoxRemoveSmallWords, 1, 1, 0, 1 );
         m_checkBoxRemoveSmallWords->setChecked( text[0] == 'T' );
-        connect( m_checkBoxRemoveSmallWords, SIGNAL( toggled( bool ) ), SIGNAL( modified() ) );
+        connect( m_checkBoxRemoveSmallWords, TQ_SIGNAL( toggled( bool ) ), TQ_SIGNAL( modified() ) );
 
         struct IdSuggestionTokenInfo info = IdSuggestions::evalToken( text.mid( 1 ) );
 
@@ -232,7 +232,7 @@ namespace KBibTeX
             m_comboBoxCasing->setCurrentItem( 2 );
         else
             m_comboBoxCasing->setCurrentItem( 0 );
-        connect( m_comboBoxCasing, SIGNAL( textChanged( const TQString& ) ), SIGNAL( modified() ) );
+        connect( m_comboBoxCasing, TQ_SIGNAL( textChanged( const TQString& ) ), TQ_SIGNAL( modified() ) );
 
         label = new TQLabel( i18n( "Only first letters:" ), this );
         layout->addWidget( label, 3, 0 );
@@ -244,7 +244,7 @@ namespace KBibTeX
         m_spinBoxLen->setSpecialValueText( i18n( "Complete title" ) );
         m_spinBoxLen->setValue( info.len > 9 ? 0 : info.len );
         m_spinBoxLen->setMinimumWidth( m_spinBoxLen->fontMetrics().width( i18n( "Complete title" ) ) + 32 );
-        connect( m_spinBoxLen, SIGNAL( valueChanged( int ) ), SIGNAL( modified() ) );
+        connect( m_spinBoxLen, TQ_SIGNAL( valueChanged( int ) ), TQ_SIGNAL( modified() ) );
 
         label = new TQLabel( i18n( "Text between words:" ), this );
         layout->addWidget( label, 4, 0 );
@@ -252,7 +252,7 @@ namespace KBibTeX
         label->setBuddy( m_lineEditInBetween );
         layout->addWidget( m_lineEditInBetween, 4, 1 );
         m_lineEditInBetween->setText( info.inBetween );
-        connect( m_lineEditInBetween, SIGNAL( textChanged( const TQString& ) ), SIGNAL( modified() ) );
+        connect( m_lineEditInBetween, TQ_SIGNAL( textChanged( const TQString& ) ), TQ_SIGNAL( modified() ) );
 
         layout->setRowStretch( 5, 1 );
         layout->setColStretch( 1, 1 );
@@ -294,7 +294,7 @@ namespace KBibTeX
         m_comboBoxDigits->insertItem( i18n( "2 digits" ) );
         m_comboBoxDigits->insertItem( i18n( "4 digits" ) );
         m_comboBoxDigits->setCurrentItem( text[0] == 'y' ? 0 : 1 );
-        connect( m_comboBoxDigits, SIGNAL( activated( int ) ), SIGNAL( modified() ) );
+        connect( m_comboBoxDigits, TQ_SIGNAL( activated( int ) ), TQ_SIGNAL( modified() ) );
 
         layout->setColStretch( 1, 1 );
         layout->setRowStretch( 2, 1 );
@@ -327,7 +327,7 @@ namespace KBibTeX
         label->setBuddy( m_lineEditInBetween );
         layout->addWidget( m_lineEditInBetween, 1, 1 );
         m_lineEditInBetween->setText( text.mid( 1 ) );
-        connect( m_lineEditInBetween, SIGNAL( textChanged( const TQString& ) ), SIGNAL( modified() ) );
+        connect( m_lineEditInBetween, TQ_SIGNAL( textChanged( const TQString& ) ), TQ_SIGNAL( modified() ) );
 
         layout->setColStretch( 1, 1 );
         layout->setRowStretch( 2, 1 );
@@ -428,9 +428,9 @@ namespace KBibTeX
             if ( component != NULL )
             {
                 ++m_componentCount;
-                connect( component, SIGNAL( moved() ), this, SLOT( updateGUI() ) );
-                connect( component, SIGNAL( deleted() ), this, SLOT( componentDeleted() ) );
-                connect( component, SIGNAL( modified() ), this, SLOT( updateExample() ) );
+                connect( component, TQ_SIGNAL( moved() ), this, TQ_SLOT( updateGUI() ) );
+                connect( component, TQ_SIGNAL( deleted() ), this, TQ_SLOT( componentDeleted() ) );
+                connect( component, TQ_SIGNAL( modified() ), this, TQ_SLOT( updateExample() ) );
             }
         }
 
@@ -484,7 +484,7 @@ namespace KBibTeX
         addMenu->insertItem( i18n( "Year" ), 2 );
         addMenu->insertItem( i18n( "Title" ), 3 );
         addMenu->insertItem( i18n( "Text" ), 4 );
-        connect( addMenu, SIGNAL( activated( int ) ), this, SLOT( addMenuActivated( int ) ) );
+        connect( addMenu, TQ_SIGNAL( activated( int ) ), this, TQ_SLOT( addMenuActivated( int ) ) );
         m_pushButtonAdd->setPopup( addMenu );
     }
 
@@ -506,9 +506,9 @@ namespace KBibTeX
 
             comp->show();
 
-            connect( comp, SIGNAL( moved() ), this, SLOT( updateGUI() ) );
-            connect( comp, SIGNAL( deleted() ), this, SLOT( componentDeleted() ) );
-            connect( comp, SIGNAL( modified() ), this, SLOT( updateExample() ) );
+            connect( comp, TQ_SIGNAL( moved() ), this, TQ_SLOT( updateGUI() ) );
+            connect( comp, TQ_SIGNAL( deleted() ), this, TQ_SLOT( componentDeleted() ) );
+            connect( comp, TQ_SIGNAL( modified() ), this, TQ_SLOT( updateExample() ) );
             m_listOfComponents->adjustSize();
             m_scrollViewComponents->ensureVisible( 10, m_listOfComponents->height() - 2 );
             updateGUI();
