@@ -167,10 +167,10 @@ namespace KBibTeX
         vboxLayout->setStretchFactor( m_listViewAlternatives, 3 );
         label->setBuddy( m_listViewAlternatives );
 
-        connect( m_listViewClique, SIGNAL( doubleClicked( TQListViewItem * ) ), this, SLOT( slotPreviewElement( TQListViewItem * ) ) );
-        connect( this, SIGNAL( user1Clicked() ), this, SLOT( slotNextClique() ) );
-        connect( this, SIGNAL( user2Clicked() ), this, SLOT( slotPreviousClique() ) );
-        connect( this, SIGNAL( okClicked() ), this, SLOT( saveCurrentMergeSet() ) );
+        connect( m_listViewClique, TQ_SIGNAL( doubleClicked( TQListViewItem * ) ), this, TQ_SLOT( slotPreviewElement( TQListViewItem * ) ) );
+        connect( this, TQ_SIGNAL( user1Clicked() ), this, TQ_SLOT( slotNextClique() ) );
+        connect( this, TQ_SIGNAL( user2Clicked() ), this, TQ_SLOT( slotPreviousClique() ) );
+        connect( this, TQ_SIGNAL( okClicked() ), this, TQ_SLOT( saveCurrentMergeSet() ) );
     }
 
     void MergeElements::setClique( int cliqueIndex )
@@ -188,7 +188,7 @@ namespace KBibTeX
             if ( entry != NULL )
             {
                 MergeElementsCliqueItem *item = new MergeElementsCliqueItem( entry, NULL, NULL, m_listViewClique );
-                connect( item, SIGNAL( stateChanged( MergeElementsCliqueItem* ) ), this, SLOT( slotRefreshAlternatives() ) );
+                connect( item, TQ_SIGNAL( stateChanged( MergeElementsCliqueItem* ) ), this, TQ_SLOT( slotRefreshAlternatives() ) );
             }
             else
             {
@@ -196,7 +196,7 @@ namespace KBibTeX
                 if ( macro != NULL )
                 {
                     MergeElementsCliqueItem *item = new MergeElementsCliqueItem( NULL, macro, NULL, m_listViewClique );
-                    connect( item, SIGNAL( stateChanged( MergeElementsCliqueItem* ) ), this, SLOT( slotRefreshAlternatives() ) );
+                    connect( item, TQ_SIGNAL( stateChanged( MergeElementsCliqueItem* ) ), this, TQ_SLOT( slotRefreshAlternatives() ) );
                 }
                 else
                 {
@@ -204,7 +204,7 @@ namespace KBibTeX
                     if ( preamble!=NULL )
                     {
                         MergeElementsCliqueItem *item = new MergeElementsCliqueItem( NULL, NULL, preamble, m_listViewClique );
-                        connect( item, SIGNAL( stateChanged( MergeElementsCliqueItem* ) ), this, SLOT( slotRefreshAlternatives() ) );
+                        connect( item, TQ_SIGNAL( stateChanged( MergeElementsCliqueItem* ) ), this, TQ_SLOT( slotRefreshAlternatives() ) );
                     }
                 }
             }
@@ -774,7 +774,7 @@ namespace KBibTeX
         int scnum = TQApplication::desktop()->screenNumber( parentWidget() );
         TQRect desk = TQApplication::desktop()->screenGeometry( scnum );
         int w, h;
-#if defined Q_WS_X11
+#if defined TQ_WS_X11
         // save maximalization as desktop size + 1 in that direction
         KWin::WindowInfo info = KWin::windowInfo( winId(), NET::WMState );
         w = info.state() & NET::MaxHoriz ? desk.width() + 1 : width();
@@ -805,7 +805,7 @@ namespace KBibTeX
     void MergeElements::showEvent( TQShowEvent * )
     {
         tqDebug( "showEvent" );
-        TQTimer::singleShot( 10, this, SLOT( slotRestore() ) );
+        TQTimer::singleShot( 10, this, TQ_SLOT( slotRestore() ) );
     }
 
     void MergeElements::slotRestore()
@@ -838,7 +838,7 @@ namespace KBibTeX
         }
         if ( !size.isEmpty() )
         {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
             int state = ( size.width() > desk.width() ? NET::MaxHoriz : 0 )
                         | ( size.height() > desk.height() ? NET::MaxVert : 0 );
             if (( state & NET::Max ) == NET::Max )
