@@ -171,7 +171,7 @@ namespace KBibTeX
         IdSuggestionsListViewItem * item = new IdSuggestionsListViewItem( m_listIdSuggestions, "a|Y|T", m_example );
         item->setPixmap( 0, SmallIcon( "filter" ) );
         m_listIdSuggestions->setSelected( item, TRUE );
-        TQTimer::singleShot( 100, this, SLOT( slotEditIdSuggestion() ) );
+        TQTimer::singleShot( 100, this, TQ_SLOT( slotEditIdSuggestion() ) );
     }
 
     void SettingsIdSuggestions::slotEditIdSuggestion()
@@ -338,34 +338,34 @@ namespace KBibTeX
         m_listIdSuggestions->header()->setClickEnabled( FALSE );
         m_listIdSuggestions->setFullWidth( true );
         gridLayout->addMultiCellWidget( m_listIdSuggestions, 0, 6, 0, 0 );
-        connect( m_listIdSuggestions, SIGNAL( selectionChanged() ), this, SLOT( updateGUI() ) );
-        connect( m_listIdSuggestions, SIGNAL( currentChanged( TQListViewItem * ) ), this, SLOT( updateGUI() ) );
-        connect( m_listIdSuggestions, SIGNAL( doubleClicked( TQListViewItem*, const TQPoint &, int ) ), this, SLOT( slotEditIdSuggestion() ) );
+        connect( m_listIdSuggestions, TQ_SIGNAL( selectionChanged() ), this, TQ_SLOT( updateGUI() ) );
+        connect( m_listIdSuggestions, TQ_SIGNAL( currentChanged( TQListViewItem * ) ), this, TQ_SLOT( updateGUI() ) );
+        connect( m_listIdSuggestions, TQ_SIGNAL( doubleClicked( TQListViewItem*, const TQPoint &, int ) ), this, TQ_SLOT( slotEditIdSuggestion() ) );
 
         m_buttonNewIdSuggestion = new KPushButton( i18n( "id suggestion",  "New" ), this );
         m_buttonNewIdSuggestion->setIconSet( TQIconSet( SmallIcon( "add" ) ) );
         gridLayout->addWidget( m_buttonNewIdSuggestion, 0, 1 );
-        connect( m_buttonNewIdSuggestion, SIGNAL( clicked() ), this, SLOT( slotNewIdSuggestion() ) );
+        connect( m_buttonNewIdSuggestion, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotNewIdSuggestion() ) );
         m_buttonEditIdSuggestion = new KPushButton( i18n( "id suggestion", "Edit" ), this );
         m_buttonEditIdSuggestion->setIconSet( TQIconSet( SmallIcon( "edit" ) ) );
         gridLayout->addWidget( m_buttonEditIdSuggestion, 1, 1 );
-        connect( m_buttonEditIdSuggestion, SIGNAL( clicked() ), this, SLOT( slotEditIdSuggestion() ) );
+        connect( m_buttonEditIdSuggestion, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotEditIdSuggestion() ) );
         m_buttonDeleteIdSuggestion = new KPushButton( i18n( "id suggestion", "Delete" ), this );
         m_buttonDeleteIdSuggestion->setIconSet( TQIconSet( SmallIcon( "edit-delete" ) ) );
         gridLayout->addWidget( m_buttonDeleteIdSuggestion, 2, 1 );
-        connect( m_buttonDeleteIdSuggestion, SIGNAL( clicked() ), this, SLOT( slotDeleteIdSuggestion() ) );
+        connect( m_buttonDeleteIdSuggestion, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotDeleteIdSuggestion() ) );
         m_buttonMoveUpIdSuggestion = new KPushButton( i18n( "id suggestion", "Up" ), this );
         m_buttonMoveUpIdSuggestion->setIconSet( TQIconSet( SmallIcon( "go-up" ) ) );
         gridLayout->addWidget( m_buttonMoveUpIdSuggestion, 3, 1 );
-        connect( m_buttonMoveUpIdSuggestion, SIGNAL( clicked() ), this, SLOT( slotMoveUpIdSuggestion() ) );
+        connect( m_buttonMoveUpIdSuggestion, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotMoveUpIdSuggestion() ) );
         m_buttonMoveDownIdSuggestion = new KPushButton( i18n( "id suggestion", "Down" ), this );
         m_buttonMoveDownIdSuggestion->setIconSet( TQIconSet( SmallIcon( "go-down" ) ) );
         gridLayout->addWidget( m_buttonMoveDownIdSuggestion, 4, 1 );
-        connect( m_buttonMoveDownIdSuggestion, SIGNAL( clicked() ), this, SLOT( slotMoveDownIdSuggestion() ) );
+        connect( m_buttonMoveDownIdSuggestion, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotMoveDownIdSuggestion() ) );
         m_buttonToggleDefault = new KPushButton( i18n( "Toogle default" ), this );
         m_buttonToggleDefault->setIconSet( TQIconSet( SmallIcon( "favorites" ) ) );
         gridLayout->addWidget( m_buttonToggleDefault, 5, 1 );
-        connect( m_buttonToggleDefault, SIGNAL( clicked() ), this, SLOT( slotToggleDefault() ) );
+        connect( m_buttonToggleDefault, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotToggleDefault() ) );
 
         m_checkBoxForceDefault = new TQCheckBox( i18n( "Use default id suggestion when editing new entries" ), this );
         gridLayout->addMultiCellWidget( m_checkBoxForceDefault, 7, 7, 0, 1 );
@@ -375,25 +375,25 @@ namespace KBibTeX
         m_lineEditSmallWords = new KLineEdit( this );
         label->setBuddy( m_lineEditSmallWords );
         gridLayout->addWidget( m_lineEditSmallWords, 10, 0 );
-        connect( m_lineEditSmallWords, SIGNAL( textChanged( const TQString & ) ), this, SLOT( slotEditSmallWordsChanged( const TQString & ) ) );
+        connect( m_lineEditSmallWords, TQ_SIGNAL( textChanged( const TQString & ) ), this, TQ_SLOT( slotEditSmallWordsChanged( const TQString & ) ) );
         m_buttonAddSmallWord = new KPushButton( i18n( "Add" ), this );
         m_buttonAddSmallWord->setEnabled( false );
         m_buttonAddSmallWord->setIconSet( TQIconSet( SmallIcon( "add" ) ) );
         gridLayout->addWidget( m_buttonAddSmallWord, 10, 1 );
-        connect( m_buttonAddSmallWord, SIGNAL( clicked() ), this, SLOT( slotAddSmallWord() ) );
+        connect( m_buttonAddSmallWord, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotAddSmallWord() ) );
 
         m_listSmallWords = new TDEListView( this );
         m_listSmallWords->addColumn( i18n( "Small Words" ) );
         m_listSmallWords->header()->setClickEnabled( true );
         m_listSmallWords->setFullWidth( true );
-        connect( m_listSmallWords, SIGNAL( selectionChanged() ), this, SLOT( slotListSmallWordsChanged() ) );
-        connect( m_listSmallWords, SIGNAL( currentChanged( TQListViewItem * ) ), this, SLOT( slotListSmallWordsChanged() ) );
+        connect( m_listSmallWords, TQ_SIGNAL( selectionChanged() ), this, TQ_SLOT( slotListSmallWordsChanged() ) );
+        connect( m_listSmallWords, TQ_SIGNAL( currentChanged( TQListViewItem * ) ), this, TQ_SLOT( slotListSmallWordsChanged() ) );
         gridLayout->addMultiCellWidget( m_listSmallWords, 11, 12, 0, 0 );
         m_buttonDeleteSmallWord = new KPushButton( i18n( "Delete" ), this );
         m_buttonDeleteSmallWord->setEnabled( false );
         m_buttonDeleteSmallWord->setIconSet( TQIconSet( SmallIcon( "edit-delete" ) ) );
         gridLayout->addWidget( m_buttonDeleteSmallWord, 11, 1 );
-        connect( m_buttonDeleteSmallWord, SIGNAL( clicked() ), this, SLOT( slotDeleteSmallWord() ) );
+        connect( m_buttonDeleteSmallWord, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotDeleteSmallWord() ) );
     }
 }
 
