@@ -84,7 +84,7 @@ namespace KBibTeX
         item->setPixmap( 0, SmallIcon( "package" ) );
         m_listKeywords->setSelected( item, TRUE );
         m_listKeywords->ensureItemVisible( item );
-        TQTimer::singleShot( 100, this, SLOT( slotEditKeyword() ) );
+        TQTimer::singleShot( 100, this, TQ_SLOT( slotEditKeyword() ) );
     }
 
     void SettingsKeyword::slotEditKeyword()
@@ -177,15 +177,15 @@ namespace KBibTeX
         m_buttonImportKeywords->setIconSet( TQIconSet( SmallIcon( "openfile" ) ) );
         TQToolTip::add( m_buttonImportKeywords, "Import all keywords from the current BibTeX file" );
         gridLayout->addWidget( m_buttonImportKeywords, 4, 1 );
-        connect( m_buttonImportKeywords, SIGNAL( clicked() ), this, SLOT( slotImportKeywords() ) );
+        connect( m_buttonImportKeywords, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotImportKeywords() ) );
 
-        connect( m_buttonNewKeyword, SIGNAL( clicked() ), this, SLOT( slotNewKeyword() ) );
-        connect( m_buttonEditKeyword, SIGNAL( clicked() ), this, SLOT( slotEditKeyword() ) );
-        connect( m_buttonDeleteKeyword, SIGNAL( clicked() ), this, SLOT( slotDeleteKeyword() ) );
-        connect( m_listKeywords, SIGNAL( selectionChanged() ), this, SLOT( updateGUI() ) );
-        connect( m_listKeywords, SIGNAL( currentChanged( TQListViewItem * ) ), this, SLOT( updateGUI() ) );
-        connect( m_listKeywords, SIGNAL( doubleClicked( TQListViewItem*, const TQPoint &, int ) ), this, SLOT( slotEditKeyword() ) );
-        connect( m_listKeywords, SIGNAL( itemRenamed( TQListViewItem* ) ), this, SLOT( slotItemRenamed( TQListViewItem* ) ) );
+        connect( m_buttonNewKeyword, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotNewKeyword() ) );
+        connect( m_buttonEditKeyword, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotEditKeyword() ) );
+        connect( m_buttonDeleteKeyword, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotDeleteKeyword() ) );
+        connect( m_listKeywords, TQ_SIGNAL( selectionChanged() ), this, TQ_SLOT( updateGUI() ) );
+        connect( m_listKeywords, TQ_SIGNAL( currentChanged( TQListViewItem * ) ), this, TQ_SLOT( updateGUI() ) );
+        connect( m_listKeywords, TQ_SIGNAL( doubleClicked( TQListViewItem*, const TQPoint &, int ) ), this, TQ_SLOT( slotEditKeyword() ) );
+        connect( m_listKeywords, TQ_SIGNAL( itemRenamed( TQListViewItem* ) ), this, TQ_SLOT( slotItemRenamed( TQListViewItem* ) ) );
 
         updateGUI();
     }
