@@ -189,18 +189,18 @@ namespace KBibTeX
         m_buttonMoveUpField = new KPushButton( i18n( "user-defined input", "Up" ), this );
         m_buttonMoveUpField->setIconSet( TQIconSet( SmallIcon( "go-up" ) ) );
         gridLayout->addWidget( m_buttonMoveUpField, 3, 1 );
-        connect( m_buttonMoveUpField, SIGNAL( clicked() ), this, SLOT( slotMoveUpField() ) );
+        connect( m_buttonMoveUpField, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotMoveUpField() ) );
         m_buttonMoveDownField = new KPushButton( i18n( "user-defined input",  "Down" ), this );
         m_buttonMoveDownField->setIconSet( TQIconSet( SmallIcon( "go-down" ) ) );
         gridLayout->addWidget( m_buttonMoveDownField, 4, 1 );
-        connect( m_buttonMoveDownField, SIGNAL( clicked() ), this, SLOT( slotMoveDownField() ) );
+        connect( m_buttonMoveDownField, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotMoveDownField() ) );
 
-        connect( m_buttonNewField, SIGNAL( clicked() ), this, SLOT( slotNewField() ) );
-        connect( m_buttonEditField, SIGNAL( clicked() ), this, SLOT( slotEditField() ) );
-        connect( m_buttonDeleteField, SIGNAL( clicked() ), this, SLOT( slotDeleteField() ) );
-        connect( m_listFields, SIGNAL( selectionChanged() ), this, SLOT( updateGUI() ) );
-        connect( m_listFields, SIGNAL( doubleClicked( TQListViewItem*, const TQPoint &, int ) ), this, SLOT( slotEditField() ) );
-        connect( m_listFields, SIGNAL( currentChanged( TQListViewItem * ) ), this, SLOT( updateGUI() ) );
+        connect( m_buttonNewField, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotNewField() ) );
+        connect( m_buttonEditField, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotEditField() ) );
+        connect( m_buttonDeleteField, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotDeleteField() ) );
+        connect( m_listFields, TQ_SIGNAL( selectionChanged() ), this, TQ_SLOT( updateGUI() ) );
+        connect( m_listFields, TQ_SIGNAL( doubleClicked( TQListViewItem*, const TQPoint &, int ) ), this, TQ_SLOT( slotEditField() ) );
+        connect( m_listFields, TQ_SIGNAL( currentChanged( TQListViewItem * ) ), this, TQ_SLOT( updateGUI() ) );
 
         updateGUI();
     }
@@ -241,8 +241,8 @@ namespace KBibTeX
         else
             fieldDlg->enableButton( KDialogBase::Ok, false );
 
-        connect( m_lineEditName, SIGNAL( textChanged( const TQString & ) ), this, SLOT( updateDialogGUI() ) );
-        connect( m_lineEditLabel, SIGNAL( textChanged( const TQString & ) ), this, SLOT( updateDialogGUI() ) );
+        connect( m_lineEditName, TQ_SIGNAL( textChanged( const TQString & ) ), this, TQ_SLOT( updateDialogGUI() ) );
+        connect( m_lineEditLabel, TQ_SIGNAL( textChanged( const TQString & ) ), this, TQ_SLOT( updateDialogGUI() ) );
         if ( fieldDlg->exec() == TQDialog::Accepted )
         {
             if ( item == NULL )
