@@ -132,14 +132,14 @@ namespace KBibTeX
         layout->addMultiCellWidget( m_listAvailableItems, 1, 1, 0, 2 );
 
         m_popupMenu = new TDEPopupMenu( m_listAvailableItems );
-        m_popupMenu->insertItem( i18n( "Rename all occurrences" ), this, SLOT( startRenaming() ) );
+        m_popupMenu->insertItem( i18n( "Rename all occurrences" ), this, TQ_SLOT( startRenaming() ) );
 
-        connect( m_listAvailableItems, SIGNAL( selectionChanged() ), this, SLOT( prepareSearch() ) );
-        connect( m_listTypeList, SIGNAL( activated( int ) ), this, SLOT( refreshLists() ) );
-        connect( m_buttonToggleShowAll, SIGNAL( toggled( bool ) ), this, SLOT( toggleShowAll( bool ) ) );
-        connect( m_buttonToggleMultiSelect, SIGNAL( toggled( bool ) ), this, SLOT( toggleMultiSelect( bool ) ) );
-        connect( m_listAvailableItems, SIGNAL( contextMenuRequested( TQListViewItem*, const TQPoint&, int ) ), this, SLOT( showContextMenu( TQListViewItem*, const TQPoint& ) ) );
-        connect( m_listAvailableItems, SIGNAL( itemRenamed( TQListViewItem*, int, const TQString& ) ), this, SLOT( endRenaming( TQListViewItem*, int, const TQString& ) ) );
+        connect( m_listAvailableItems, TQ_SIGNAL( selectionChanged() ), this, TQ_SLOT( prepareSearch() ) );
+        connect( m_listTypeList, TQ_SIGNAL( activated( int ) ), this, TQ_SLOT( refreshLists() ) );
+        connect( m_buttonToggleShowAll, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( toggleShowAll( bool ) ) );
+        connect( m_buttonToggleMultiSelect, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( toggleMultiSelect( bool ) ) );
+        connect( m_listAvailableItems, TQ_SIGNAL( contextMenuRequested( TQListViewItem*, const TQPoint&, int ) ), this, TQ_SLOT( showContextMenu( TQListViewItem*, const TQPoint& ) ) );
+        connect( m_listAvailableItems, TQ_SIGNAL( itemRenamed( TQListViewItem*, int, const TQString& ) ), this, TQ_SLOT( endRenaming( TQListViewItem*, int, const TQString& ) ) );
 
         toggleShowAll( FALSE );
     }
