@@ -170,8 +170,8 @@ namespace KBibTeX
         KURL url = KURL( TQString( "http://www.arxiv.org/find/all/1/all:+%2/0/1/0/all/0/1?per_page=%1" ).arg( m_numberOfResults ).arg( query.replace( "%", "%25" ).replace( "+", "%2B" ).replace( " ", "%20" ).replace( "#", "%23" ).replace( "&", "%26" ).replace( "?", "%3F" ) ) );
         m_currentJobMutex.lock();
         TDEIO::Job *job = TDEIO::storedGet( url, FALSE, FALSE );
-        connect( job, SIGNAL( result( TDEIO::Job * ) ), this, SLOT( unlockJob( TDEIO::Job * ) ) );
-        connect( job, SIGNAL( result( TDEIO::Job * ) ), this, SLOT( arXivResult( TDEIO::Job * ) ) );
+        connect( job, TQ_SIGNAL( result( TDEIO::Job * ) ), this, TQ_SLOT( unlockJob( TDEIO::Job * ) ) );
+        connect( job, TQ_SIGNAL( result( TDEIO::Job * ) ), this, TQ_SLOT( arXivResult( TDEIO::Job * ) ) );
     }
 
     void WebQueryArXiv::unlockJob( TDEIO::Job * )
@@ -227,8 +227,8 @@ namespace KBibTeX
         m_aborted = false;
         m_currentJobMutex.lock();
         TDEIO::Job *job = TDEIO::storedGet( abstractURL, FALSE, FALSE );
-        connect( job, SIGNAL( result( TDEIO::Job * ) ), this, SLOT( unlockJob( TDEIO::Job * ) ) );
-        connect( job, SIGNAL( result( TDEIO::Job * ) ), this, SLOT( arXivAbstractResult( TDEIO::Job * ) ) );
+        connect( job, TQ_SIGNAL( result( TDEIO::Job * ) ), this, TQ_SLOT( unlockJob( TDEIO::Job * ) ) );
+        connect( job, TQ_SIGNAL( result( TDEIO::Job * ) ), this, TQ_SLOT( arXivAbstractResult( TDEIO::Job * ) ) );
     }
 
     void WebQueryArXiv::arXivAbstractResult( TDEIO::Job *job )
@@ -554,8 +554,8 @@ namespace KBibTeX
                 m_urls.remove( url );
                 m_currentJobMutex.lock();
                 TDEIO::Job *job = TDEIO::storedGet( url, FALSE, FALSE );
-                connect( job, SIGNAL( result( TDEIO::Job * ) ), this, SLOT( unlockJob( TDEIO::Job * ) ) );
-                connect( job, SIGNAL( result( TDEIO::Job * ) ), this, SLOT( arXivAbstractResult( TDEIO::Job * ) ) );
+                connect( job, TQ_SIGNAL( result( TDEIO::Job * ) ), this, TQ_SLOT( unlockJob( TDEIO::Job * ) ) );
+                connect( job, TQ_SIGNAL( result( TDEIO::Job * ) ), this, TQ_SLOT( arXivAbstractResult( TDEIO::Job * ) ) );
             }
             else
                 setEndSearch( WebQuery::statusSuccess );
