@@ -113,8 +113,8 @@ namespace KBibTeX
         m_transferJobBuffer = new TQBuffer();
         m_transferJobBuffer->open( IO_WriteOnly );
         TDEIO::TransferJob* m_transferJob = TDEIO::get( KURL( "http://scholar.google.com/scholar_ncr" ), false, false );
-        connect( m_transferJob, SIGNAL( data( TDEIO::Job *, const TQByteArray & ) ), this, SLOT( slotData( TDEIO::Job *, const TQByteArray & ) ) );
-        connect( m_transferJob, SIGNAL( result( TDEIO::Job * ) ), this, SLOT( slotFinishedStartpage( TDEIO::Job * ) ) );
+        connect( m_transferJob, TQ_SIGNAL( data( TDEIO::Job *, const TQByteArray & ) ), this, TQ_SLOT( slotData( TDEIO::Job *, const TQByteArray & ) ) );
+        connect( m_transferJob, TQ_SIGNAL( result( TDEIO::Job * ) ), this, TQ_SLOT( slotFinishedStartpage( TDEIO::Job * ) ) );
     }
 
     void WebQueryGoogleScholar::cancelQuery()
@@ -154,8 +154,8 @@ namespace KBibTeX
         m_transferJobBuffer = new TQBuffer();
         m_transferJobBuffer->open( IO_WriteOnly );
         TDEIO::TransferJob* m_transferJob = TDEIO::get( KURL( "http://scholar.google.com/scholar_preferences?hl=en" ), false, false );
-        connect( m_transferJob, SIGNAL( data( TDEIO::Job *, const TQByteArray & ) ), this, SLOT( slotData( TDEIO::Job *, const TQByteArray & ) ) );
-        connect( m_transferJob, SIGNAL( result( TDEIO::Job * ) ), this, SLOT( slotFinishedLoadingSettings( TDEIO::Job * ) ) );
+        connect( m_transferJob, TQ_SIGNAL( data( TDEIO::Job *, const TQByteArray & ) ), this, TQ_SLOT( slotData( TDEIO::Job *, const TQByteArray & ) ) );
+        connect( m_transferJob, TQ_SIGNAL( result( TDEIO::Job * ) ), this, TQ_SLOT( slotFinishedLoadingSettings( TDEIO::Job * ) ) );
 
     }
 
@@ -198,8 +198,8 @@ namespace KBibTeX
         m_transferJobBuffer = new TQBuffer();
         m_transferJobBuffer->open( IO_WriteOnly );
         TDEIO::TransferJob* m_transferJob = TDEIO::get( nextUrl, false, false );
-        connect( m_transferJob, SIGNAL( data( TDEIO::Job *, const TQByteArray & ) ), this, SLOT( slotData( TDEIO::Job *, const TQByteArray & ) ) );
-        connect( m_transferJob, SIGNAL( result( TDEIO::Job * ) ), this, SLOT( slotFinishedSavingSettings( TDEIO::Job * ) ) );
+        connect( m_transferJob, TQ_SIGNAL( data( TDEIO::Job *, const TQByteArray & ) ), this, TQ_SLOT( slotData( TDEIO::Job *, const TQByteArray & ) ) );
+        connect( m_transferJob, TQ_SIGNAL( result( TDEIO::Job * ) ), this, TQ_SLOT( slotFinishedSavingSettings( TDEIO::Job * ) ) );
     }
 
     void WebQueryGoogleScholar::slotFinishedSavingSettings( TDEIO::Job *job )
@@ -239,8 +239,8 @@ namespace KBibTeX
         m_transferJobBuffer = new TQBuffer();
         m_transferJobBuffer->open( IO_WriteOnly );
         TDEIO::TransferJob* m_transferJob = TDEIO::get( nextUrl, false, false );
-        connect( m_transferJob, SIGNAL( data( TDEIO::Job *, const TQByteArray & ) ), this, SLOT( slotData( TDEIO::Job *, const TQByteArray & ) ) );
-        connect( m_transferJob, SIGNAL( result( TDEIO::Job * ) ), this, SLOT( slotFinishedReceivingResultOverview( TDEIO::Job * ) ) );
+        connect( m_transferJob, TQ_SIGNAL( data( TDEIO::Job *, const TQByteArray & ) ), this, TQ_SLOT( slotData( TDEIO::Job *, const TQByteArray & ) ) );
+        connect( m_transferJob, TQ_SIGNAL( result( TDEIO::Job * ) ), this, TQ_SLOT( slotFinishedReceivingResultOverview( TDEIO::Job * ) ) );
     }
 
     void WebQueryGoogleScholar::slotFinishedReceivingResultOverview( TDEIO::Job *job )
