@@ -148,7 +148,7 @@ namespace KBibTeX
                 doc.setContent( &buffer );
                 TQDomElement docElem = doc.documentElement();
                 WebQueryPubMedResultParser resultParser;
-                connect( &resultParser, SIGNAL( foundEntry( BibTeX::Entry*, bool ) ), this, SIGNAL( foundEntry( BibTeX::Entry*, bool ) ) );
+                connect( &resultParser, TQ_SIGNAL( foundEntry( BibTeX::Entry*, bool ) ), this, TQ_SIGNAL( foundEntry( BibTeX::Entry*, bool ) ) );
                 resultParser.parse( docElem );
                 buffer.close();
                 setEndSearch( WebQuery::statusSuccess );
